SPC (Ethernet) - Heros Devices 0.10.3 documentation

Skip to content
Back to top
View this page

# SPC (Ethernet)

From: Gamma Vacuum

Class: `herosdevices.hardware.gamma_vacuum.EthernetSPC`

Driver Quality Index: beta

Controller for the Gamma vacuum SPC Ion pump controllers with network interface.

Arguments

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.gamma_vacuum.EthernetSPC` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
address | <class ‘str’> |  |
observables | dict | None | None | Dictionary of attributes which should be exposed at datasource `_observable_data()` events. Of the form {“attribute_name”: {“name”: “display_name”, “unit”: “unit”}}.
timeout | <class ‘float’> | 1.0 |

Example JSON for BOSS

The following JSON strings can be used to start a HERO device representation of `EthernetSPC` using BOSS.

    {
        "_id": "my_EthernetSPC",
        "classname": "herosdevices.hardware.gamma_vacuum.EthernetSPC",
        "arguments": {
            "address": "<class 'str'>",
            "observables": null,
            "timeout": 1.0
        }
    }

generated from signature

Inheritance